# Analysis for the paper/ chapter Home-based virtual reality Exposure Therapy with virtual health agent support
#
# Hartanto, D., Brinkman, W. P., Kampmann, I. L., Morina, N., Emmelkamp, P. G., & Neerincx, M. A. (2015, September). 
# Home-Based Virtual Reality Exposure Therapy with Virtual Health Agent Support. In International Symposium on Pervasive 
# Computing Paradigms for Mental Health (pp. 85-98). Springer International Publishing.
#
# 2018
# Output file will be create 
## capture all the output to a file.


# Adjust this to root folder that contain data files
setwd("D:/Surfdrive/PhD Research/#4/R_chapter_05/")

# Capture all the output to a file
sink("data_analyses_homebased_VRET_system_with_virtual_health_agent_support.txt")

# Print R version and operating system version used by this data analyses
sessionInfo()

############################################### LIBRARIES ###############################################
# Libraries used for this analyses 
library(Rcmdr)
library(foreign)
library(nlme)
library(lattice, pos=18)

################################################ DATA ####################################################

# File: r_data_exp.csv
# 1. pid: participants ID
# 2. gender: gender of participants
# 3. age: age of participants
# 4. total_ipq: total score of participants IPQ questionnaires
#
# File: r_data.sav
# 1. SUD: Subjective Unit of Discomfort of participants
# 2. HR: heart rate measurement of participants
# 3. Session: session number during the whole experiments (2 - 9). Seesion 1 and 10 were used for questionnaires and reflection purposes.
# 4. Time: time of measurements during the sesssion. It records measurements point in every 4 minutes.
# 5. PID1: participant ID1
# 6. PID2: participant ID2
# 7. PID3: participant ID3
# 8. PID4: participant ID4
# 9. PID5: participant ID5
# 10. ExpNumber: exposure number during a session (1 - 3)
# 11. SUD_center: center avg points of SUD score
# 12. HR_center: center avg points of HR measurements
#
#

############################################### FUNCTIONS ###############################################
# Collection of functions used for this study

# print the mean and standard deviation
mean_sd <- function(data, text){
  cat(text," Mean: ", mean(data, na.rm = TRUE), " SD: ", sd(data, na.rm=TRUE), "\n") 
}

sample_count <- function(data, text){
  cat(text, nrow(data), "\n")
}

# count gender variable
count_gender <- function(x){
  cat("Female:", length(x[x == "female"]), "Male: ", length(x[x == "male"]), "\n")
}

cat("############################################### ANALYSES ###############################################")
# Data reading
data_exp <- read.csv("r_data_exp.csv")
data_online <- read.csv("r_data_online.csv")
VRdata <- read.spss("r_data.sav", use.value.labels=TRUE, to.data.frame=TRUE)

# create signle variable participants by combining all individual Boolean variable whether data coming from this individual participant
VRdata$Participant <- log2(VRdata$PID1*2^1 + VRdata$PID2*2^2 + VRdata$PID3*2^3 + VRdata$PID4*2^4 + VRdata$PID5*2^5)

##################### SUBJECT ######################
cat("\nSubject analysis\n")
data_exp$gender <- factor(data_exp$gender, levels = c(0,1), labels = c("male", "female"))
count_gender(data_exp$gender)
cat("Participant age range: ", range(data_exp$age), "\n")
mean_sd(data_exp$age, "Participants age M and SD: ")

######################## IPQ #######################

cat("The overall IPQ results were compared with online IPQ dataset: \n")
#calculate the total online IPQ
data_online$total_ipq <- (rowMeans(data_online[1:14], na.rm = TRUE)) * (ncol(data_online) - 1)


# Taken From https://stats.stackexchange.com/questions/15722/how-to-use-levene-test-function-in-r#15723
#General code to reshape two vectors into a long data.frame
twoVarWideToLong <- function(sample1,sample2) {
  res <- data.frame(
    GroupID=as.factor(c(rep(1, length(sample1)), rep(2, length(sample2)))),
    DV=c(sample1, sample2)
  )   
}   

# (Step 1) Reshaping the example data
long.data <- twoVarWideToLong(data_online$total_ipq, data_exp$total_ipq)

# (Step 2) There are many different calls here that will work... but here is an example
leveneTest(DV~GroupID,long.data)

# (Step 3) As Levenetest is sign, homogeneity of variance should not be assumpted
t.test(data_online$total_ipq, data_exp$total_ipq, paired = FALSE, var.equal = FALSE, alternative = "t")

sample_count(data_exp, "N of experiment data: ")
mean_sd(data_exp$total_ipq, "Mean and SD experiment IPQ: ")
sample_count(data_online, "N of online data: ")
mean_sd(data_online$total_ipq, "Mean and SD online IPQ:")

######################## Plots ######################

#variable for plot
VRdata$exposure <- (VRdata$Session-2)*3+VRdata$ExpNumber

# Plot Heart rate
scatterplot(HR~exposure, reg.line=FALSE, smooth=TRUE, spread=TRUE, boxplots=FALSE, 
  span=0.5, jitter=list(x=1, y=1), xlab="Exposure number across sessions", ylab="Heart rate", 
  cex.axis=0.7, data=VRdata)

#Plot SUD score  
scatterplot(SUD~exposure, reg.line=FALSE, smooth=TRUE, spread=TRUE, boxplots=FALSE, 
  span=0.5, jitter=list(x=1, y=1), xlab="Exposure number across sessions", ylab="SUD score", 
  cex.axis=0.7, data=VRdata)

############################# analysis SUD score   
cat("\n\nData file has ",nrow(VRdata)," SUD scores.\n\n")

baselineSUD <- lme(SUD_center ~ 1, random = ~ 1|Participant/Session/ExpNumber/Time, data = VRdata, method = "ML")
SessionModelSUD <-update(baselineSUD, .~. + Session)
ExpNumberModelSUD <-update(SessionModelSUD, .~. + ExpNumber)
SessionExpNumerModelSUD <- update(ExpNumberModelSUD, .~. + Session:ExpNumber)


cat("\nComparing model fit for SUD score data\n")
anova(baselineSUD,SessionModelSUD,ExpNumberModelSUD, SessionExpNumerModelSUD)


############################# analysis HR score
cat("\n\nData file has ",nrow(VRdata)," Heart rate measurements\n\n")
baselineHR <- lme(HR_center ~ 1, random = ~ 1|Participant/Session/ExpNumber/Time, data = VRdata, method = "ML")
SessionModelHR <-update(baselineHR, .~. + Session)
ExpNumberModelHR <-update(SessionModelHR, .~. + ExpNumber)
SessionExpNumerModelHR <- update(ExpNumberModelHR, .~. + Session:ExpNumber)

cat("\nComparing model fit for Heart Rate data data\n")
anova(baselineHR,SessionModelHR,ExpNumberModelHR, SessionExpNumerModelHR)

## stop redireting output.
sink()

